@@ -17,7 +17,9 @@ CREATE TABLE `carp_schedule_job_group`
 ) ENGINE=InnoDB COMMENT='schedule job group';
 
 INSERT INTO `carp_schedule_job_group` (`id`, `namespace`, `name`, `remark`, `creator`, `editor`)
-VALUES (1, 'default', 'default', NULL, 'sys', 'sys');
+VALUES (1, 'system', 'system', NULL, 'sys', 'sys');
+INSERT INTO `carp_schedule_job_group` (`id`, `namespace`, `name`, `remark`, `creator`, `editor`)
+VALUES (2, 'default', 'default', NULL, 'sys', 'sys');
 
 DROP TABLE IF EXISTS `carp_schedule_job_config`;
 CREATE TABLE `carp_schedule_job_config`
@@ -27,6 +29,7 @@ CREATE TABLE `carp_schedule_job_config`
     `type`         varchar(8)  NOT NULL COMMENT '类型。系统、用户',
     `engine_type`  varchar(8)  NOT NULL COMMENT '引擎类型。内置、temporal、DolphinScheduler',
     `job_type`     varchar(8)  NOT NULL COMMENT '任务类型。normal、workflow',
+    `execute_type` varchar(8)  NOT NULL COMMENT '执行方式。native, method, bean',
     `name`         varchar(64) NOT NULL COMMENT '任务名称',
     `handler`      varchar(64) COMMENT '任务处理器',
     `remark`       varchar(255) COMMENT 'remark',
@@ -38,9 +41,14 @@ CREATE TABLE `carp_schedule_job_config`
     UNIQUE KEY `uniq_group_name` (`job_group_id`,`name`)
 ) ENGINE=InnoDB COMMENT='schedule job config';
 
-INSERT INTO `carp_schedule_job_config` (`id`, `job_group_id`, `type`, `engine_type`, `job_type`, `name`, `handler`, `remark`,
-                                   `creator`, `editor`)
-VALUES (1, 1, '0', 'internal', '0', 'demo', NULL, NULL, 'sys', 'sys');
+INSERT INTO `carp_schedule_job_config` (`id`, `job_group_id`, `type`, `engine_type`, `job_type`, `execute_type`,
+                                        `name`, `handler`, `remark`, `creator`, `editor`)
+VALUES (1, 1, '0', 'internal', '0', 'method', 'demo-mothod', 'execute', NULL, 'sys', 'sys');
+
+INSERT INTO `carp_schedule_job_config` (`id`, `job_group_id`, `type`, `engine_type`, `job_type`, `execute_type`,
+                                        `name`, `handler`, `remark`, `creator`, `editor`)
+VALUES (2, 1, '0', 'internal', '0', 'bean', 'demo-bean', 'cn.sliew.carp.module.scheduler.demo.CarpDemoJobHandler',
+        NULL, 'sys', 'sys');
 
 DROP TABLE IF EXISTS `carp_schedule_job_instance`;
 CREATE TABLE `carp_schedule_job_instance`
@@ -65,14 +73,27 @@ CREATE TABLE `carp_schedule_job_instance`
 ) ENGINE=InnoDB COMMENT='schedule job instance';
 
 INSERT INTO `carp_schedule_job_instance` (`id`, `job_config_id`, `name`, `cron`, `timezone`, `start_time`, `end_time`,
-                                     `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
+                                          `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
 VALUES (1, 1, 'high', '0/10 * * * * ?', 'GMT+8', '2024-01-01 00:00:00', '9999-01-01 00:00:00', NULL, NULL, NULL, '0',
         NULL, 'sys', 'sys');
 INSERT INTO `carp_schedule_job_instance` (`id`, `job_config_id`, `name`, `cron`, `timezone`, `start_time`, `end_time`,
-                                     `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
+                                          `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
 VALUES (2, 1, 'middle', '0 0/1 * * * ?', 'GMT+8', '2024-01-01 00:00:00', '9999-01-01 00:00:00', NULL, NULL, NULL, '0',
         NULL, 'sys', 'sys');
 INSERT INTO `carp_schedule_job_instance` (`id`, `job_config_id`, `name`, `cron`, `timezone`, `start_time`, `end_time`,
-                                     `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
+                                          `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
 VALUES (3, 1, 'high', '0 0/5 * * * ?', 'GMT+8', '2024-01-01 00:00:00', '9999-01-01 00:00:00', NULL, NULL, NULL, '0',
         NULL, 'sys', 'sys');
+
+INSERT INTO `carp_schedule_job_instance` (`id`, `job_config_id`, `name`, `cron`, `timezone`, `start_time`, `end_time`,
+                                          `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
+VALUES (4, 2, 'high', '0/10 * * * * ?', 'GMT+8', '2024-01-01 00:00:00', '9999-01-01 00:00:00', NULL, NULL, NULL, '0',
+        NULL, 'sys', 'sys');
+INSERT INTO `carp_schedule_job_instance` (`id`, `job_config_id`, `name`, `cron`, `timezone`, `start_time`, `end_time`,
+                                          `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
+VALUES (5, 2, 'middle', '0 0/1 * * * ?', 'GMT+8', '2024-01-01 00:00:00', '9999-01-01 00:00:00', NULL, NULL, NULL, '0',
+        NULL, 'sys', 'sys');
+INSERT INTO `carp_schedule_job_instance` (`id`, `job_config_id`, `name`, `cron`, `timezone`, `start_time`, `end_time`,
+                                          `props`, `params`, `timeout`, `status`, `remark`, `creator`, `editor`)
+VALUES (6, 2, 'high', '0 0/5 * * * ?', 'GMT+8', '2024-01-01 00:00:00', '9999-01-01 00:00:00', NULL, NULL, NULL, '0',
+        NULL, 'sys', 'sys');
